diff formatoutput.py @ 5:b4c750fe0fe3 draft

planemo upload for repository https://github.com/galaxyproject/tools-iuc/tree/master/tools/metaphlan/ commit f3a89af137b13715f9fb13383577aceb2c445ce6
author iuc
date Sat, 03 Dec 2022 10:42:36 +0000
parents b6ecdfac241f
children
line wrap: on
line diff
--- a/formatoutput.py	Wed Feb 02 22:02:12 2022 +0000
+++ b/formatoutput.py	Sat Dec 03 10:42:36 2022 +0000
@@ -57,9 +57,11 @@
                 # skip headers
                 if line.startswith("#"):
                     continue
-                # skip UNKNOWN lines in Predicted taxon relative abundances
-                if "UNKNOWN" in line:
+
+                # skip UNKNOWN (v3) or UNCLASSIFIED (v4) lines in predicted taxon relative abundances
+                if "UNKNOWN" in line or 'UNCLASSIFIED' in line:
                     continue
+
                 # spit lines
                 split_line = line[:-1].split('\t')
                 taxo_n = split_line[0].split('|')